@@ -7,6 +7,7 @@ import (
 
 	"github.com/bluekeyes/go-gitdiff/gitdiff"
 
+	"github.com/dlvhdr/diffnav/pkg/constants"
 	"github.com/dlvhdr/diffnav/pkg/filenode"
 )
 
@@ -16,18 +17,18 @@ func sortFiles(files []*gitdiff.File) {
 		nameB := filenode.GetFileName(b)
 		dira := filepath.Dir(nameA)
 		dirb := filepath.Dir(nameB)
-		if dira != "." && dirb != "." && dira == dirb {
+		if dira != constants.RootName && dirb != constants.RootName && dira == dirb {
 			return strings.Compare(strings.ToLower(nameA), strings.ToLower(nameB))
 		}
 
-		if dira != "." && dirb == "." {
+		if dira != constants.RootName && dirb == constants.RootName {
 			return -1
 		}
-		if dirb != "." && dira == "." {
+		if dirb != constants.RootName && dira == constants.RootName {
 			return 1
 		}
 
-		if dira != "." && dirb != "." {
+		if dira != constants.RootName && dirb != constants.RootName {
 			if strings.HasPrefix(dira, dirb) {
 				return -1
 			}
